@@ -155,25 +155,26 @@ class VPS(_defaults_.Defaults):
 			return r3sponse.error(f"Failed to deploy website {self.domain} on vps {self.ip}, error: {response.error}.", log_level=log_level)
 
 		# execute installer script.
-		if log_level >= 0: loader.mark(new_message=f"Executing installer script of website {self.domain} on vps {self.ip}")
-		response = ssht00ls.ssh.command(
-			alias=self.domain,
-			command=f"chmod +x {tmp}/requirements/installer && bash {tmp}/requirements/installer{installer_arguments}",
-			log_level=-1,)
-		if not response.success: 
-			if log_level >= 0: loader.stop(success=False)
-			return r3sponse.error(f"Failed to deploy website {self.domain} on vps {self.ip}, error: {response.error}.", log_level=log_level)
+		if not code_update:
+			if log_level >= 0: loader.mark(new_message=f"Executing installer script of website {self.domain} on vps {self.ip}")
+			response = ssht00ls.ssh.command(
+				alias=self.domain,
+				command=f"chmod +x {tmp}/requirements/installer && bash {tmp}/requirements/installer{installer_arguments}",
+				log_level=-1,)
+			if not response.success: 
+				if log_level >= 0: loader.stop(success=False)
+				return r3sponse.error(f"Failed to deploy website {self.domain} on vps {self.ip}, error: {response.error}.", log_level=log_level)
 
-		# deploy.
-		if log_level >= 0: loader.mark(new_message=f"Deploying domain {self.domain} on vps {self.ip}")
-		output = ssht00ls.ssh.command(
-			alias=self.domain,
-			command=f"python3 {installed_location}/website.py --deploy{installer_arguments} --non-interactive",
-			log_level=-1,)
-		if not output.success or "Successfully deployed domain https://" not in output:
-			#print(response)
-			if log_level >= 0: loader.stop(success=False)
-			return r3sponse.error(f"Failed to deploy website {self.domain} on vps {self.ip}, error: {output}.", log_level=log_level)
+			# deploy.
+			if log_level >= 0: loader.mark(new_message=f"Deploying domain {self.domain} on vps {self.ip}")
+			output = ssht00ls.ssh.command(
+				alias=self.domain,
+				command=f"python3 {installed_location}/website.py --deploy{installer_arguments} --non-interactive",
+				log_level=-1,)
+			if not output.success or "Successfully deployed domain https://" not in output:
+				#print(response)
+				if log_level >= 0: loader.stop(success=False)
+				return r3sponse.error(f"Failed to deploy website {self.domain} on vps {self.ip}, error: {output}.", log_level=log_level)
 
 		# handler.
 		if log_level >= 0: loader.stop()
